@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -28,6 +42,8 @@
 #include <QPainter>
 #include <QPainterPath>
 #include <QSpinBox>
+#include <QLabel>
+#include <QToolTip>
 
 #include <stdlib.h>
 
@@ -50,10 +66,12 @@ static QPixmap genIcon(const QSize &iconSize, const QString &, const QColor &col
 static QPixmap genIcon(const QSize &iconSize, int number, const QColor &color)
 { return genIcon(iconSize, QString::number(number), color); }
 
-ToolBar::ToolBar(QWidget *parent)
+ToolBar::ToolBar(const QString &title, QWidget *parent)
     : QToolBar(parent), spinbox(0), spinboxAction(0)
 {
-    setWindowTitle(tr("Main Tool Bar"));
+    tip = 0;
+    setWindowTitle(title);
+    setObjectName(title);
 
     setIconSize(QSize(32, 32));
 
@@ -143,11 +161,14 @@ ToolBar::ToolBar(QWidget *parent)
     areaActions->addAction(topAction);
     areaActions->addAction(bottomAction);
 
+    toolBarBreakAction = new QAction(tr("Insert break"), this);
+    connect(toolBarBreakAction, SIGNAL(triggered(bool)), this, SLOT(insertToolBarBreak()));
+
     connect(movableAction, SIGNAL(triggered(bool)), areaActions, SLOT(setEnabled(bool)));
 
     connect(movableAction, SIGNAL(triggered(bool)), allowedAreasActions, SLOT(setEnabled(bool)));
 
-    menu = new QMenu(tr("&Toolbar"), this);
+    menu = new QMenu(title, this);
     menu->addAction(toggleViewAction());
     menu->addSeparator();
     menu->addAction(orderAction);
@@ -161,12 +182,15 @@ ToolBar::ToolBar(QWidget *parent)
     menu->addActions(allowedAreasActions->actions());
     menu->addSeparator();
     menu->addActions(areaActions->actions());
+    menu->addSeparator();
+    menu->addAction(toolBarBreakAction);
+
+    connect(menu, SIGNAL(aboutToShow()), this, SLOT(updateMenu()));
 
     randomize();
 }
 
-
-void ToolBar::polishEvent(QEvent *)
+void ToolBar::updateMenu()
 {
     QMainWindow *mainWindow = qobject_cast<QMainWindow *>(parentWidget());
     Q_ASSERT(mainWindow != 0);
@@ -313,3 +337,43 @@ void ToolBar::placeTop(bool p)
 
 void ToolBar::placeBottom(bool p)
 { place(Qt::BottomToolBarArea, p); }
+
+void ToolBar::insertToolBarBreak()
+{
+    QMainWindow *mainWindow = qobject_cast<QMainWindow *>(parentWidget());
+    Q_ASSERT(mainWindow != 0);
+
+    mainWindow->insertToolBarBreak(this);
+}
+
+void ToolBar::enterEvent(QEvent*)
+{
+/*
+    These labels on top of toolbars look darn ugly
+
+    if (tip == 0) {
+        tip = new QLabel(windowTitle(), this);
+        QPalette pal = tip->palette();
+        QColor c = Qt::black;
+        c.setAlpha(100);
+        pal.setColor(QPalette::Window, c);
+        pal.setColor(QPalette::Foreground, Qt::white);
+        tip->setPalette(pal);
+        tip->setAutoFillBackground(true);
+        tip->setMargin(3);
+        tip->setText(windowTitle());
+    }
+    QPoint c = rect().center();
+    QSize hint = tip->sizeHint();
+    tip->setGeometry(c.x() - hint.width()/2, c.y() - hint.height()/2,
+                        hint.width(), hint.height());
+
+    tip->show();
+*/
+}
+
+void ToolBar::leaveEvent(QEvent*)
+{
+    if (tip != 0)
+        tip->hide();
+}
