@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -26,7 +40,7 @@
 
 #include <QtGui>
 
-class QBypassWidget;
+QT_FORWARD_DECLARE_CLASS(QBypassWidget)
 
 class HoverPoints : public QObject
 {
@@ -124,10 +138,10 @@ private:
 inline QRectF HoverPoints::pointBoundingRect(int i) const
 {
     QPointF p = m_points.at(i);
-    double w = m_pointSize.width();
-    double h = m_pointSize.height();
-    double x = p.x() - w / 2;
-    double y = p.y() - h / 2;
+    qreal w = m_pointSize.width();
+    qreal h = m_pointSize.height();
+    qreal x = p.x() - w / 2;
+    qreal y = p.y() - h / 2;
     return QRectF(x, y, w, h);
 }
 
