@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -54,6 +48,7 @@ public:
         { return &static_cast<QtMetaObject*>(0)->staticQtMetaObject; }
 };
 
+//! [0]
 class TetrixUiLoader : public QUiLoader
 {
 public:
@@ -71,27 +66,35 @@ public:
         return QUiLoader::createWidget(className, parent, name);
     }
 };
+//! [0]
 
 static QScriptValue evaluateFile(QScriptEngine &engine, const QString &fileName)
 {
     QFile file(fileName);
     file.open(QIODevice::ReadOnly);
-    return engine.evaluate(file.readAll());
+    return engine.evaluate(file.readAll(), fileName);
 }
 
 int main(int argc, char *argv[])
 {
+    Q_INIT_RESOURCE(tetrix);
+
+//! [1]
     QApplication app(argc, argv);
     QScriptEngine engine;
 
     QScriptValue Qt = engine.newQMetaObject(QtMetaObject::get());
     Qt.setProperty("App", engine.newQObject(&app));
     engine.globalObject().setProperty("Qt", Qt);
+//! [1]
 
+//! [2]
     evaluateFile(engine, ":/tetrixpiece.js");
     evaluateFile(engine, ":/tetrixboard.js");
     evaluateFile(engine, ":/tetrixwindow.js");
+//! [2]
 
+//! [3]
     TetrixUiLoader loader;
     QFile uiFile(":/tetrixwindow.ui");
     uiFile.open(QIODevice::ReadOnly);
@@ -99,12 +102,15 @@ int main(int argc, char *argv[])
     uiFile.close();
 
     QScriptValue ctor = engine.evaluate("TetrixWindow");
-    QScriptValue scriptUi = engine.newQObject(ui);
+    QScriptValue scriptUi = engine.newQObject(ui, QScriptEngine::ScriptOwnership);
     QScriptValue tetrix = ctor.construct(QScriptValueList() << scriptUi);
+//! [3]
 
+//! [4]
     ui->resize(550, 370);
     ui->show();
 
     qsrand(QTime(0,0,0).secsTo(QTime::currentTime()));
     return app.exec();
+//! [4]
 }
