@@ -1,36 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -38,6 +39,7 @@
 #include "dirmodel.h"
 #include "mainwindow.h"
 
+//! [0]
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), completer(0), lineEdit(0)
 {
@@ -69,18 +71,24 @@ MainWindow::MainWindow(QWidget *parent)
     caseCombo->addItem(tr("Case Insensitive"));
     caseCombo->addItem(tr("Case Sensitive"));
     caseCombo->setCurrentIndex(0);
+//! [0]
 
+//! [1]
     wrapCheckBox = new QCheckBox;
     wrapCheckBox->setText(tr("Wrap around completions"));
     wrapCheckBox->setChecked(true);
+//! [1]
 
+//! [2]
     contentsLabel = new QLabel;
     contentsLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
     connect(modelCombo, SIGNAL(activated(int)), this, SLOT(changeModel()));
     connect(modeCombo, SIGNAL(activated(int)), this, SLOT(changeMode(int)));
     connect(caseCombo, SIGNAL(activated(int)), this, SLOT(changeCase(int)));
+//! [2]
 
+//! [3]
     lineEdit = new QLineEdit;
     
     QGridLayout *layout = new QGridLayout;
@@ -98,7 +106,9 @@ MainWindow::MainWindow(QWidget *parent)
     setWindowTitle(tr("Completer"));
     lineEdit->setFocus();
 }
+//! [3]
 
+//! [4]
 void MainWindow::createMenu()
 {
     QAction *exitAction = new QAction(tr("Exit"), this);
@@ -116,14 +126,20 @@ void MainWindow::createMenu()
     helpMenu->addAction(aboutAct);
     helpMenu->addAction(aboutQtAct);
 }
+//! [4]
 
+//! [5]
 QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
 {
     QFile file(fileName);
     if (!file.open(QFile::ReadOnly))
         return new QStringListModel(completer);
+//! [5]
 
+//! [6]
+#ifndef QT_NO_CURSOR
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+#endif
     QStringList words;
 
     while (!file.atEnd()) {
@@ -132,14 +148,21 @@ QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
             words << line.trimmed();
     }
 
+#ifndef QT_NO_CURSOR
     QApplication::restoreOverrideCursor();
+#endif
+//! [6]
 
+//! [7]
     if (!fileName.contains(QLatin1String("countries.txt")))
         return new QStringListModel(words, completer);
+//! [7]
 
     // The last two chars of the countries.txt file indicate the country
     // symbol. We put that in column 2 of a standard item model
+//! [8]
     QStandardItemModel *m = new QStandardItemModel(words.count(), 2, completer);
+//! [8] //! [9]
     for (int i = 0; i < words.count(); ++i) {
         QModelIndex countryIdx = m->index(i, 0);
         QModelIndex symbolIdx = m->index(i, 1);
@@ -151,7 +174,9 @@ QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
 
     return m;
 }
+//! [9]
 
+//! [10]
 void MainWindow::changeMode(int index)
 {
     QCompleter::CompletionMode mode;
@@ -164,12 +189,14 @@ void MainWindow::changeMode(int index)
 
     completer->setCompletionMode(mode);
 }
+//! [10]
 
 void MainWindow::changeCase(int cs)
 {
     completer->setCaseSensitivity(cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
 }
 
+//! [11]
 void MainWindow::changeModel()
 {
     delete completer;
@@ -184,6 +211,7 @@ void MainWindow::changeModel()
             contentsLabel->setText(tr("Enter file path"));
         }
         break;
+//! [11] //! [12]
     case 1:
         { // DirModel that shows full paths
             DirModel *dirModel = new DirModel(completer);
@@ -191,6 +219,7 @@ void MainWindow::changeModel()
             contentsLabel->setText(tr("Enter file path"));
         }
         break;
+//! [12] //! [13]
     case 2:
         { // Country List
             completer->setModel(modelFromFile(":/resources/countries.txt"));
@@ -204,6 +233,7 @@ void MainWindow::changeModel()
             contentsLabel->setText(tr("Enter name of your country"));
         }
         break;
+//! [13] //! [14]
     case 3:
         { // Word list
             completer->setModel(modelFromFile(":/resources/wordlist.txt"));
@@ -219,9 +249,12 @@ void MainWindow::changeModel()
     lineEdit->setCompleter(completer);
     connect(wrapCheckBox, SIGNAL(clicked(bool)), completer, SLOT(setWrapAround(bool)));
 }
+//! [14]
 
+//! [15]
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About"), tr("This example demonstrates the "
         "different features of the QCompleter class."));
 }
+//! [15]
