@@ -1,23 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -67,7 +81,9 @@ void PaintArea::setImage(const QImage &image)
 void PaintArea::insertShape(const QPainterPath &path)
 {
     pendingPath = path;
+#ifndef QT_NO_CURSOR
     setCursor(Qt::CrossCursor);
+#endif
 }
 
 void PaintArea::setBrushColor(const QColor &color)
@@ -80,11 +96,13 @@ void PaintArea::setBrushWidth(int width)
     thickness = width;
 }
 
+//! [0]
 void PaintArea::setBrush(BrushInterface *brushInterface, const QString &brush)
 {
     this->brushInterface = brushInterface;
     this->brush = brush;
 }
+//! [0]
 
 QSize PaintArea::sizeHint() const
 {
@@ -116,7 +134,9 @@ void PaintArea::mousePressEvent(QMouseEvent *event)
             painter.drawPath(pendingPath);
 
             pendingPath = QPainterPath();
+#ifndef QT_NO_CURSOR
             unsetCursor();
+#endif
             update();
         } else {
             if (brushInterface) {
@@ -132,6 +152,7 @@ void PaintArea::mousePressEvent(QMouseEvent *event)
     }
 }
 
+//! [1]
 void PaintArea::mouseMoveEvent(QMouseEvent *event)
 {
     if ((event->buttons() & Qt::LeftButton) && lastPos != QPoint(-1, -1)) {
@@ -146,6 +167,7 @@ void PaintArea::mouseMoveEvent(QMouseEvent *event)
         lastPos = event->pos();
     }
 }
+//! [1]
 
 void PaintArea::mouseReleaseEvent(QMouseEvent *event)
 {
